@@ -1,6 +1,7 @@
 from texbld.docker.client import dockerclient
 
 from typing import TYPE_CHECKING
+import texbld.logger as logger
 
 if TYPE_CHECKING:
     from texbld.common.image import Image
@@ -8,11 +9,13 @@ if TYPE_CHECKING:
 
 
 def build_image(image: 'Image', cache=False):
-    print(f"Copying {image.docker_image_name()}...")
+    logger.progress(f"Copying {image.docker_image_name()}...")
     image.copy_to_builds(cache=cache)
-    print(f"Building {image.docker_image_name()}...")
+    logger.done(f"Copied {image.docker_image_name()}")
+    logger.progress(f"Building {image.docker_image_name()}...")
     dockerclient.images.build(path=image.build_dir(),
                               tag=image.docker_image_name(), quiet=False)
+    logger.done(f"Finished building {image.docker_image_name()}")
 
 
 def build(solver: 'Solver', cache=False):
