@@ -5,6 +5,7 @@ from texbld.config import PROJECT_CONFIG_FILE
 from texbld.scaffold.copy import copy_image
 from texbld.scaffold.project import project_toml_gen
 from texbld.common.solver import Solver
+import texbld.logger as logger
 
 
 def scaffold_project(image: Image, directory: str):
@@ -14,9 +15,10 @@ def scaffold_project(image: Image, directory: str):
         raise FileExistsError(directory)
     os.makedirs(directory)
     for img in reversed(Solver(image).images()):
-        print("copying image", img.package_dir())
         if not img.is_base():
+            logger.progress("copying image", img.package_dir())
             copy_image(img, directory)
+            logger.done("copied", img.package_dir())
     configpath = os.path.join(directory, PROJECT_CONFIG_FILE)
     with open(configpath, "w") as w:
         w.write(project_toml_gen(name, image))
@@ -31,4 +33,5 @@ def scaffold_image(directory: str):
     src = os.path.join(os.path.dirname(__file__), "sample_image")
     shutil.copytree(src, directory)
     text = open(os.path.join(directory, "image.toml")).read()
-    open(os.path.join(directory, "image.toml"), "w").write(text.replace("image_name", name))
+    open(os.path.join(directory, "image.toml"), "w").write(
+        text.replace("image_name", name))
